@@ -4,7 +4,6 @@ import os
 import glob
 import json
 import contextlib
-import pprint
 
 from bcbio.utils import tmpfile, file_exists
 from bcbio.distributed.transaction import file_transaction
@@ -12,7 +11,6 @@ from bcbio.broad.picardrun import picard_rnaseq_metrics
 
 import pysam
 
-
 class PicardMetricsParser(object):
     """Read metrics files produced by Picard analyses.
 
@@ -79,7 +77,6 @@ class PicardMetricsParser(object):
         paired = insert_vals is not None
 
         total = align_vals["TOTAL_READS"]
-        dup_total = int(dup_vals.get("READ_PAIRS_EXAMINED", 0))
         align_total = int(align_vals["PF_READS_ALIGNED"])
         out.append(("Total", _add_commas(str(total)),
                     ("paired" if paired else "")))
@@ -90,13 +87,11 @@ class PicardMetricsParser(object):
                                            align_vals["READS_ALIGNED_IN_PAIRS"],
                                            total))
             align_total = int(align_vals["READS_ALIGNED_IN_PAIRS"])
-            if dup_total > 0:
-                if align_total != dup_total:
-                    out.append(("Alignment combinations",
-                                _add_commas(str(dup_total)), ""))
+            dup_total = dup_vals.get("READ_PAIR_DUPLICATES")
+            if dup_total is not None:
                 out.append(self._count_percent("Pair duplicates",
                                                dup_vals["READ_PAIR_DUPLICATES"],
-                                               dup_total))
+                                               align_total))
             std = insert_vals.get("STANDARD_DEVIATION", "?")
             std_dev = "+/- %.1f" % float(std.replace(",", ".")) if (std and std != "?") else ""
             out.append(("Insert size",
@@ -233,12 +228,19 @@ class PicardMetricsParser(object):
         return vals
 
     def _parse_dup_metrics(self, in_handle):
-        want_stats = ["READ_PAIRS_EXAMINED", "READ_PAIR_DUPLICATES",
-                "PERCENT_DUPLICATION", "ESTIMATED_LIBRARY_SIZE"]
-        header = self._read_off_header(in_handle)
-        info = in_handle.readline().rstrip("\n").split("\t")
-        vals = self._read_vals_of_interest(want_stats, header, info)
-        return vals
+        if in_handle.readline().find("picard.metrics") > 0:
+            want_stats = ["READ_PAIRS_EXAMINED", "READ_PAIR_DUPLICATES",
+                    "PERCENT_DUPLICATION", "ESTIMATED_LIBRARY_SIZE"]
+            header = self._read_off_header(in_handle)
+            info = in_handle.readline().rstrip("\n").split("\t")
+            vals = self._read_vals_of_interest(want_stats, header, info)
+            return vals
+        else:
+            vals = {}
+            for line in in_handle:
+                metric, val = line.rstrip().split("\t")
+                vals[metric] = val
+            return vals
 
     def _parse_insert_metrics(self, in_handle):
         want_stats = ["MEDIAN_INSERT_SIZE", "MIN_INSERT_SIZE",
@@ -281,22 +283,28 @@ class PicardMetrics(object):
         self._tmp_dir = tmp_dir
         self._parser = PicardMetricsParser()
 
-    def report(self, align_bam, ref_file, is_paired, bait_file, target_file):
+    def report(self, align_bam, ref_file, is_paired, bait_file, target_file,
+               variant_region_file):
         """Produce report metrics using Picard with sorted aligned BAM file.
         """
-        dup_bam, dup_metrics = self._get_current_dup_metrics(align_bam)
-        align_metrics = self._collect_align_metrics(dup_bam, ref_file)
+        dup_metrics = self._get_current_dup_metrics(align_bam)
+        align_metrics = self._collect_align_metrics(align_bam, ref_file)
         # Prefer the GC metrics in FastQC instead of Picard
-        # gc_graph, gc_metrics = self._gc_bias(dup_bam, ref_file)
+        # gc_graph, gc_metrics = self._gc_bias(align_bam, ref_file)
         gc_graph = None
         insert_graph, insert_metrics, hybrid_metrics = (None, None, None)
         if is_paired:
-            insert_graph, insert_metrics = self._insert_sizes(dup_bam)
+            insert_graph, insert_metrics = self._insert_sizes(align_bam)
         if bait_file and target_file:
-            hybrid_metrics = self._hybrid_select_metrics(dup_bam,
+            assert os.path.exists(bait_file), (bait_file, "does not exist!")
+            assert os.path.exists(target_file), (target_file, "does not exist!")
+            hybrid_metrics = self._hybrid_select_metrics(align_bam,
                                                          bait_file, target_file)
+        elif variant_region_file:
+            hybrid_metrics = self._hybrid_select_metrics(
+                align_bam, variant_region_file, variant_region_file)
 
-        vrn_vals = self._variant_eval_metrics(dup_bam)
+        vrn_vals = self._variant_eval_metrics(align_bam)
         summary_info = self._parser.get_summary_metrics(align_metrics,
                 dup_metrics, insert_metrics, hybrid_metrics,
                 vrn_vals)
@@ -308,16 +316,20 @@ class PicardMetrics(object):
         return summary_info, graphs
 
     def _get_current_dup_metrics(self, align_bam):
-        """Retrieve existing duplication metrics file, or generate if not present.
+        """Retrieve duplicate information from input BAM file.
         """
-        dup_fname_pos = align_bam.find("-dup")
-        if dup_fname_pos > 0:
-            base_name = align_bam[:dup_fname_pos]
-            metrics = glob.glob("{0}*.dup_metrics".format(base_name))
-            assert len(metrics) > 0, "Appear to have deduplication but did not find metrics file"
-            return align_bam, metrics[0]
-        else:
-            return align_bam, None
+        metrics_file = "%s.dup_metrics" % os.path.splitext(align_bam)[0]
+        if not file_exists(metrics_file):
+            dups = 0
+            with contextlib.closing(pysam.Samfile(align_bam, "rb")) as bam_handle:
+                for read in bam_handle:
+                    if (read.is_paired and read.is_read1) or not read.is_paired:
+                        if read.is_duplicate:
+                            dups += 1
+            with open(metrics_file, "w") as out_handle:
+                out_handle.write("# custom bcbio-nextgen metrics\n")
+                out_handle.write("READ_PAIR_DUPLICATES\t%s\n" % dups)
+        return metrics_file
 
     def _check_metrics_file(self, bam_name, metrics_ext):
         """Check for an existing metrics file for the given BAM.
