@@ -12,7 +12,7 @@ import os
 import copy
 
 from bcbio import utils
-from bcbio.log import setup_logging, logger
+from bcbio.log import logger
 from bcbio.pipeline import config_utils
 
 from cluster_helper import cluster as ipython_cluster
@@ -30,11 +30,28 @@ def dictadd(orig, k, v):
         new["view"] = view
     return new
 
-def find_cores_per_job(fn, parallel, item_count, config):
+def _get_resource_programs(fn, algs):
+    """Retrieve programs used in analysis based on algorithm configurations.
+
+    Helps avoid requiring core information from unused programs.
+    """
+    # standard list of programs we always use
+    used_progs = set(["gatk", "gemini"])
+    for alg in algs:
+        # get aligners used
+        aligner = alg.get("aligner")
+        if aligner:
+            used_progs.add(aligner)
+    for prog in (fn.metadata.get("resources", []) if hasattr(fn, "metadata") else []):
+        if prog in used_progs:
+            yield prog
+
+def find_cores_per_job(fn, parallel, items, config):
     """Determine cores and workers to use for this stage based on function metadata.
     """
     all_cores = [1]
-    for prog in (fn.metadata.get("resources", []) if hasattr(fn, "metadata") else []):
+    algs = [get_algorithm_config(x) for x in items]
+    for prog in _get_resource_programs(fn, algs):
         resources = config_utils.get_resources(prog, config)
         cores = resources.get("cores")
         if cores:
@@ -42,7 +59,7 @@ def find_cores_per_job(fn, parallel, item_count, config):
     cores_per_job = max(all_cores)
     total = parallel["cores"]
     if total > cores_per_job:
-        return min(total // cores_per_job, item_count), cores_per_job
+        return min(total // cores_per_job, len(items)), cores_per_job
     else:
         return 1, total
 
@@ -56,13 +73,23 @@ def _get_checkpoint_file(cdir, fn_name):
     return fname
 
 def is_std_config_arg(x):
-    return (isinstance(x, dict) and x.has_key("algorithm") and x.has_key("resources"))
+    return isinstance(x, dict) and "algorithm" in x and "resources" in x and not "files" in x
 
 def is_nested_config_arg(x):
-    return (isinstance(x, dict) and x.has_key("config") and
-            is_std_config_arg(x["config"]))
+    return isinstance(x, dict) and "config" in x and is_std_config_arg(x["config"])
 
-def add_cores_to_config(args, cores_per_job):
+def get_algorithm_config(xs):
+    """Flexibly extract algorithm configuration for a sample from any function arguments.
+    """
+    for x in xs:
+        if is_std_config_arg(x):
+            return x["algorithm"]
+        elif is_nested_config_arg(x):
+            return x["config"]["algorithm"]
+    raise ValueError("Did not find algorithm configuration in items: {0}"
+                     .format(xs))
+
+def add_cores_to_config(args, cores_per_job, parallel=None):
     """Add information about available cores for a job to configuration.
     Ugly hack to update core information in a configuration dictionary.
     """
@@ -77,8 +104,12 @@ def add_cores_to_config(args, cores_per_job):
     new_arg = copy.deepcopy(args[new_i])
     if is_nested_config_arg(new_arg):
         new_arg["config"]["algorithm"]["num_cores"] = int(cores_per_job)
+        if parallel:
+            new_arg["config"]["parallel"] = parallel
     elif is_std_config_arg(new_arg):
         new_arg["algorithm"]["num_cores"] = int(cores_per_job)
+        if parallel:
+            new_arg["parallel"] = parallel
     else:
         raise ValueError("Unexpected configuration dictionary: %s" % new_arg)
     args = list(args)[:]
@@ -94,7 +125,6 @@ def runner(parallel, fn_name, items, work_dir, config):
     A checkpoint directory keeps track of finished tasks, avoiding spinning up clusters
     for sections that have been previous processed.
     """
-    setup_logging(config)
     out = []
     checkpoint_dir = utils.safe_makedir(os.path.join(work_dir, "checkpoints_ipython"))
     checkpoint_file = _get_checkpoint_file(checkpoint_dir, fn_name)
@@ -102,7 +132,7 @@ def runner(parallel, fn_name, items, work_dir, config):
                             fromlist=["ipythontasks"]),
                  fn_name)
     items = [x for x in items if x is not None]
-    num_jobs, cores_per_job = find_cores_per_job(fn, parallel, len(items), config)
+    num_jobs, cores_per_job = find_cores_per_job(fn, parallel, items, config)
     parallel = dictadd(parallel, "cores_per_job", cores_per_job)
     parallel = dictadd(parallel, "num_jobs", num_jobs)
     # already finished, run locally on current machine to collect details
@@ -117,7 +147,7 @@ def runner(parallel, fn_name, items, work_dir, config):
     else:
         logger.info("ipython: %s" % fn_name)
         if len(items) > 0:
-            items = [add_cores_to_config(x, cores_per_job) for x in items]
+            items = [add_cores_to_config(x, cores_per_job, parallel) for x in items]
             with ipython_cluster.cluster_view(parallel["scheduler"].lower(), parallel["queue"],
                                               parallel["num_jobs"], parallel["cores_per_job"],
                                               profile=parallel["profile"]) as view:
