@@ -7,7 +7,7 @@ from IPython.parallel import require
 from bcbio.distributed import ipython
 from bcbio.pipeline import sample, lane, qcsummary, shared, variation
 from bcbio.variation import bamprep, realign, genotype, ensemble, multi, population, recalibrate
-from bcbio.log import setup_logging, logger
+from bcbio.log import logger, setup_local_logging
 
 @contextlib.contextmanager
 def _setup_logging(args):
@@ -21,12 +21,13 @@ def _setup_logging(args):
         elif ipython.is_std_config_arg(arg):
             config = arg
             break
-    if config is not None:
-        setup_logging(config)
-    else:
+    if config is None:
         raise NotImplementedError("No config in %s:" % args[0])
+    handler = setup_local_logging(config, config.get("parallel", {}))
     try:
         yield None
+        if hasattr(handler, "close"):
+            handler.close()
     except:
         logger.exception("Unexpected error")
         raise
