@@ -10,10 +10,9 @@ import subprocess
 
 from bcbio import utils
 from bcbio.distributed.transaction import file_transaction
-from bcbio.log import logger
 from bcbio.pipeline import config_utils
-from bcbio.provenance.diagnostics import log_cmd
-from bcbio.utils import (memoize_outfile, file_exists, transform_to, curdir_tmpdir)
+from bcbio.provenance import do
+from bcbio.utils import (memoize_outfile, file_exists, curdir_tmpdir)
 
 # ## BAM realignment
 
@@ -36,6 +35,7 @@ def align_bam(in_bam, ref_file, names, align_dir, config):
     resources = config_utils.get_resources("novoalign", config)
     num_cores = config["algorithm"].get("num_cores", 1)
     max_mem = resources.get("memory", "4G")
+    extra_novo_args = " ".join(_novoalign_args_from_config(config, False))
 
     if not file_exists(out_file):
         with curdir_tmpdir(base_dir=align_dir) as work_dir:
@@ -44,17 +44,22 @@ def align_bam(in_bam, ref_file, names, align_dir, config):
                 cmd = ("{novosort} -c {num_cores} -m {max_mem} --compression 0 "
                        " -n -t {work_dir} {in_bam} "
                        "| {novoalign} -o SAM '{rg_info}' -d {ref_file} -f /dev/stdin "
-                       "  -F BAMPE -c {num_cores} "
+                       "  -F BAMPE -c {num_cores} {extra_novo_args} "
                        "| {samtools} view -b -S -u - "
                        "| {novosort} -c {num_cores} -m {max_mem} -t {work_dir} "
                        "  -o {tx_out_file} /dev/stdin")
                 cmd = cmd.format(**locals())
-                log_cmd("Novoalign: %s" % names["sample"], None, cmd)
-                subprocess.check_call(cmd, shell=True)
+                do.run(cmd, "Novoalign: %s" % names["sample"], None,
+                       [do.file_nonempty(tx_out_file)])
     return out_file
 
 # ## Fastq to BAM alignment
 
+def can_pipe(fastq_file):
+    """Novoalign support piping for all read lengths.
+    """
+    return True
+
 def align_pipe(fastq_file, pair_file, ref_file, names, align_dir, config):
     """Perform piped alignment of fastq input files, generating sorted output BAM.
     """
@@ -65,28 +70,30 @@ def align_pipe(fastq_file, pair_file, ref_file, names, align_dir, config):
     resources = config_utils.get_resources("novoalign", config)
     num_cores = config["algorithm"].get("num_cores", 1)
     max_mem = resources.get("memory", "1G")
-    qual_format = config["algorithm"].get("quality_format", "").lower()
-    qual_flag = "ILMFQ" if qual_format == "illumina" else "STDFQ"
+    extra_novo_args = " ".join(_novoalign_args_from_config(config, False))
     rg_info = get_rg_info(names)
     if not utils.file_exists(out_file):
         with utils.curdir_tmpdir() as work_dir:
             with file_transaction(out_file) as tx_out_file:
                 tx_out_prefix = os.path.splitext(tx_out_file)[0]
                 cmd = ("{novoalign} -o SAM '{rg_info}' -d {ref_file} -f {fastq_file} {pair_file} "
-                       "  -F {qual_flag} -c {num_cores} "
+                       "  -c {num_cores} {extra_novo_args} "
                        "| {samtools} view -b -S -u - "
                        "| {samtools} sort -@ {num_cores} -m {max_mem} - {tx_out_prefix}")
                 cmd = cmd.format(**locals())
-                log_cmd("Novoalign: %s" % names["sample"], None, cmd)
-                subprocess.check_call(cmd, shell=True)
+                do.run(cmd, "Novoalign: %s" % names["sample"], None,
+                       [do.file_nonempty(tx_out_file)])
     return out_file
 
-def _novoalign_args_from_config(config):
+def _novoalign_args_from_config(config, need_quality=True):
     """Select novoalign options based on configuration parameters.
     """
-    qual_format = config["algorithm"].get("quality_format", "").lower()
-    qual_flags = ["-F", "ILMFQ" if qual_format == "illumina" else "STDFQ"]
-    multi_mappers = config["algorithm"].get("multiple_mappers", True)
+    if need_quality:
+        qual_format = config["algorithm"].get("quality_format", "").lower()
+        qual_flags = ["-F", "ILMFQ" if qual_format == "illumina" else "STDFQ"]
+    else:
+        qual_flags = []
+    multi_mappers = config["algorithm"].get("multiple_mappers")
     if multi_mappers is True:
         multi_flag = "Random"
     elif isinstance(multi_mappers, basestring):
@@ -94,7 +101,13 @@ def _novoalign_args_from_config(config):
     else:
         multi_flag = "None"
     multi_flags = ["-r"] + multi_flag.split()
-    extra_args = config["algorithm"].get("extra_align_args", [])
+    resources = config_utils.get_resources("novoalign", config)
+    # default arguments for improved variant calling based on
+    # comparisons to reference materials: turn off soft clipping and recalibrate
+    if resources.get("options") is None:
+        extra_args = ["-o", "FullNW", "-k"]
+    else:
+        extra_args = [str(x) for x in resources.get("options", [])]
     return qual_flags + multi_flags + extra_args
 
 # Tweaks to add
@@ -112,14 +125,13 @@ def align(fastq_file, pair_file, ref_file, out_base, align_dir, config,
         cl += extra_args if extra_args is not None else []
         cl += ["-o", "SAM"]
         if rg_name:
-            cl.append(r"@RG\tID:{0}".format(rg_name))
+            cl.append(r"'@RG\tID:{0}'".format(rg_name))
         cl += ["-d", ref_file, "-f", fastq_file]
         if pair_file:
             cl.append(pair_file)
         with file_transaction(out_file) as tx_out_file:
-            with open(tx_out_file, "w") as out_handle:
-                logger.info(" ".join([str(x) for x in cl]))
-                subprocess.check_call([str(x) for x in cl], stdout=out_handle)
+            cmd = "{cl} > {out_file}".format(cl=" ".join(cl), out_file=tx_out_file)
+            do.run(cmd, "novoalign {rg_name}".format(**locals()), None)
     return out_file
 
 # ## Indexing
