@@ -8,7 +8,7 @@ from collections import namedtuple
 from Bio.SeqIO.QualityIO import FastqGeneralIterator
 
 from bcbio import utils, broad
-from bcbio.bam import cram, fastq
+from bcbio.bam import cram
 from bcbio.ngsalign import bowtie, bwa, tophat, bowtie2, mosaik, novoalign
 from bcbio.distributed.transaction import file_transaction
 
@@ -22,18 +22,22 @@ from bcbio.distributed.transaction import file_transaction
 #  This is useful for indexes that don't have an associated location file
 #  but are stored in the same directory structure.
 NgsTool = namedtuple("NgsTool", ["align_fn", "pipe_align_fn", "bam_align_fn",
-                                 "galaxy_loc_file", "remap_index_fn"])
+                                 "galaxy_loc_file", "remap_index_fn", "can_pipe"])
 
 base_location_file = "sam_fa_indices.loc"
 _tools = {
-    "bowtie": NgsTool(bowtie.align, None, None, bowtie.galaxy_location_file, None),
-    "bowtie2": NgsTool(bowtie2.align, None, None, base_location_file, bowtie2.remap_index_fn),
-    "bwa": NgsTool(bwa.align, bwa.align_pipe, bwa.align_bam, bwa.galaxy_location_file, None),
-    "mosaik": NgsTool(mosaik.align, None, None, mosaik.galaxy_location_file, None),
-    "novoalign": NgsTool(novoalign.align, novoalign.align_pipe, novoalign.align_bam, base_location_file,
-                         novoalign.remap_index_fn),
-    "tophat": NgsTool(tophat.align, None, None, base_location_file, bowtie2.remap_index_fn),
-    "samtools": NgsTool(None, None, None, base_location_file, None),
+    "bowtie": NgsTool(bowtie.align, None, None, bowtie.galaxy_location_file, None, None),
+    "bowtie2": NgsTool(bowtie2.align, None, None, base_location_file, bowtie2.remap_index_fn,
+                       None),
+    "bwa": NgsTool(bwa.align, bwa.align_pipe, bwa.align_bam, bwa.galaxy_location_file, None,
+                   bwa.can_pipe),
+    "mosaik": NgsTool(mosaik.align, None, None, mosaik.galaxy_location_file, None,
+                      None),
+    "novoalign": NgsTool(novoalign.align, novoalign.align_pipe, novoalign.align_bam,
+                         base_location_file, novoalign.remap_index_fn, novoalign.can_pipe),
+    "tophat": NgsTool(tophat.align, None, None, base_location_file, bowtie2.remap_index_fn,
+                      None),
+    "samtools": NgsTool(None, None, None, base_location_file, None, None),
     }
 
 metadata = {"support_bam": [k for k, v in _tools.iteritems() if v.bam_align_fn is not None]}
@@ -46,7 +50,7 @@ def align_to_sort_bam(fastq1, fastq2, names, genome_build, aligner,
     align_ref, sam_ref = get_genome_ref(genome_build, aligner, dirs["galaxy"])
     if fastq1.endswith(".bam"):
         out_bam = _align_from_bam(fastq1, aligner, align_ref, sam_ref, names, align_dir, config)
-    elif fastq.readlen_supports_piping(fastq1) and _tools[aligner].pipe_align_fn:
+    elif _can_pipe(aligner, fastq1):
         out_bam = _align_from_fastq_pipe(fastq1, fastq2, aligner, align_ref, sam_ref, names,
                                          align_dir, config)
     else:
@@ -54,6 +58,13 @@ def align_to_sort_bam(fastq1, fastq2, names, genome_build, aligner,
                                     align_dir, config)
     return out_bam, sam_ref
 
+def _can_pipe(aligner, fastq_file):
+    """Check if current aligner support piping for a particular input fastq file.
+    """
+    if _tools[aligner].can_pipe and _tools[aligner].pipe_align_fn:
+        return _tools[aligner].can_pipe(fastq_file)
+    return False
+
 def _align_from_fastq_pipe(fastq1, fastq2, aligner, align_ref, sam_ref, names, align_dir, config):
     """Align longer reads using new piped strategies that avoid disk IO.
     """
