@@ -2,7 +2,6 @@
 """
 import copy
 import os
-import re
 
 from bcbio import utils, broad
 from bcbio.log import logger
@@ -11,7 +10,7 @@ from bcbio.bam.trim import brun_trim_fastq, trim_read_through
 from bcbio.pipeline.fastq import get_fastq_files, needs_fastq_conversion
 from bcbio.pipeline.demultiplex import split_by_barcode
 from bcbio.pipeline.alignment import align_to_sort_bam, get_genome_ref
-from bcbio.pipeline import cleanbam, merge, shared, sample
+from bcbio.pipeline import config_utils, cleanbam, merge, sample
 from bcbio.ngsalign.split import split_read_files
 from bcbio.variation import recalibrate
 
@@ -24,7 +23,7 @@ def _item_needs_compute(lanes):
             return True
         # check if we need to process the input by splitting or conversion
         item = lane_items[0]
-        config = shared.update_config_w_custom(config, item)
+        config = config_utils.update_w_custom(config, item)
         split_size = config.get("distributed", {}).get("align_split_size",
                                                        config["algorithm"].get("align_split_size", None))
         if split_size is not None:
@@ -57,34 +56,28 @@ def process_all_lanes(lanes, run_parallel):
 def process_lane(lane_items, fc_name, fc_date, dirs, config):
     """Prepare lanes, potentially splitting based on barcodes.
     """
-    lane_name = "%s_%s_%s" % (lane_items[0]['lane'], fc_date, fc_name)
-    logger.info("Preparing %s" % lane_name)
     full_fastq1, full_fastq2 = get_fastq_files(dirs["fastq"],
                                                dirs["work"], lane_items[0], fc_name, dirs=dirs,
-                                               config=shared.update_config_w_custom(config, lane_items[0]))
+                                               config=config_utils.update_w_custom(config, lane_items[0]))
     bc_files = split_by_barcode(full_fastq1, full_fastq2, lane_items,
-                                lane_name, dirs, config)
+                                lane_items[0]["rgnames"]["lane"], dirs, config)
     out = []
     for item in lane_items:
-        config = shared.update_config_w_custom(config, item)
+        logger.debug("Preparing %s" % item["rgnames"]["lane"])
+        config = config_utils.update_w_custom(config, item)
         # Can specify all barcodes but might not have actual sequences
         # Would be nice to have a good way to check this is okay here.
         if item["barcode_id"] in bc_files:
             for fastq1, fastq2, lane_ext in _prep_fastq_files(item, bc_files, dirs, config):
-                cur_lane_name = lane_name
-                cur_lane_desc = item["description"]
-                if item.get("name", "") and config["algorithm"].get("include_short_name", True):
-                    cur_lane_desc = "%s : %s" % (item["name"], cur_lane_desc)
                 if item["barcode_id"] is not None:
-                    cur_lane_name += "_%s" % (item["barcode_id"])
+                    item["rgnames"]["lane"] += "_%s" % (item["barcode_id"])
                 if lane_ext is not None:
-                    cur_lane_name += "_s{0}".format(lane_ext)
-                out.append((fastq1, fastq2, item, cur_lane_name, cur_lane_desc,
-                            dirs, config))
+                    item["rgnames"]["lane"] += "_s{0}".format(lane_ext)
+                out.append((fastq1, fastq2, item, dirs, config))
     return out
 
 
-def trim_lane(fastq1, fastq2, info, lane_name, lane_desc, dirs, config):
+def trim_lane(fastq1, fastq2, item, dirs, config):
     """
     if trim_reads is set with no trimmer specified, default to B-run trimming
     only. if trimmer is set to a supported type, perform that trimming
@@ -96,7 +89,7 @@ def trim_lane(fastq1, fastq2, info, lane_name, lane_desc, dirs, config):
     trim_reads = config["algorithm"].get("trim_reads", False)
     if not trim_reads:
         logger.info("Skipping trimming of %s." % (", ".join(to_trim)))
-        return [(fastq1, fastq2, info, lane_name, lane_desc, dirs, config)]
+        return [(fastq1, fastq2, item, dirs, config)]
 
     # swap the default to None if trim_reads gets deprecated
 
@@ -121,19 +114,10 @@ def trim_lane(fastq1, fastq2, info, lane_name, lane_desc, dirs, config):
     if fastq2 is not None:
         fastq2 = out_files[1]
 
-    return [(fastq1, fastq2, info, lane_name, lane_desc, dirs, config)]
+    return [(fastq1, fastq2, item, dirs, config)]
 
 # ## Alignment
 
-def rg_names(lane_name, lane_desc, config):
-    return {"rg": lane_name.split("_")[0],
-            "sample": lane_desc,
-            "lane": lane_name,
-            "pl": config["algorithm"]["platform"].lower(),
-            "pu": (lane_name.rsplit("_", 1)[0]
-                   if re.search(r"_s\d+$", lane_name) is not None
-                   else lane_name)}
-
 def link_bam_file(orig_file, new_dir):
     """Provide symlinks of BAM file and existing indexes.
     """
@@ -143,22 +127,21 @@ def link_bam_file(orig_file, new_dir):
                   "%s.bai" % os.path.splitext(orig_file)[0]):
         if utils.file_exists(fname):
             sym_file = os.path.join(new_dir, os.path.basename(fname))
-            os.symlink(fname, sym_file)
+            if not os.path.exists(sym_file):
+                os.symlink(fname, sym_file)
             update_files.append(sym_file)
     return update_files[0]
 
-def process_alignment(fastq1, fastq2, info, lane_name, lane_desc,
-                      dirs, config):
+def process_alignment(fastq1, fastq2, item, dirs, config):
     """Do an alignment of fastq files, preparing a sorted BAM output file.
     """
     aligner = config["algorithm"].get("aligner", None)
     out_bam = ""
-    names = rg_names(lane_name, lane_desc, config)
-    _, ref_file = get_genome_ref(info["genome_build"], None, dirs["galaxy"])
+    _, ref_file = get_genome_ref(item["genome_build"], None, dirs["galaxy"])
     if os.path.exists(fastq1) and aligner:
-        logger.info("Aligning lane %s with %s aligner" % (lane_name, aligner))
-        out_bam, ref_file = align_to_sort_bam(fastq1, fastq2, names,
-                                              info["genome_build"], aligner,
+        logger.info("Aligning lane %s with %s aligner" % (item["rgnames"]["lane"], aligner))
+        out_bam, ref_file = align_to_sort_bam(fastq1, fastq2, item["rgnames"],
+                                              item["genome_build"], aligner,
                                               dirs, config)
     elif os.path.exists(fastq1) and fastq1.endswith(".bam"):
         sort_method = config["algorithm"].get("bam_sort")
@@ -169,36 +152,34 @@ def process_alignment(fastq1, fastq2, info, lane_name, lane_desc,
                 os.path.splitext(os.path.basename(fastq1))[0]))
             out_bam = runner.run_fn("picard_sort", fastq1, sort_method, out_file)
         elif bamclean is True or bamclean == "picard":
-            out_bam = cleanbam.picard_prep(fastq1, names, ref_file, dirs, config)
+            out_bam = cleanbam.picard_prep(fastq1, item["rgnames"], ref_file, dirs, config)
         else:
             out_bam = link_bam_file(fastq1, os.path.join(dirs["work"], "prealign",
-                                                         names["sample"]))
+                                                         item["rgnames"]["sample"]))
     if not out_bam and not os.path.exists(fastq1):
         raise ValueError("Could not find input file: %s" % fastq1)
-    return [{"fastq": [fastq1, fastq2], "work_bam": out_bam, "info": info,
+    return [{"fastq": [fastq1, fastq2], "work_bam": out_bam, "info": item,
              "sam_ref": ref_file, "config": config}]
 
-def align_prep_full(fastq1, fastq2, info, lane_name, lane_desc,
-                    dirs, config, config_file):
+def align_prep_full(fastq1, fastq2, item, dirs, config, config_file):
     """Perform alignment and post-processing required on full BAM files.
     Prepare list of callable genome regions allowing subsequent parallelization.
     """
-    if fastq1 is None and "vrn_file" in info:
-        _, ref_file = get_genome_ref(info["genome_build"], None, dirs["galaxy"])
+    if fastq1 is None and "vrn_file" in item:
+        _, ref_file = get_genome_ref(item["genome_build"], None, dirs["galaxy"])
         config["algorithm"]["variantcaller"] = ""
-        data = {"info": info, "sam_ref": ref_file,
+        data = {"info": item, "sam_ref": ref_file,
                 "work_bam": None,
-                "genome_build": info["genome_build"],
-                "name": ("", lane_desc),
-                "vrn_file": info["vrn_file"],
+                "genome_build": item["genome_build"],
+                "name": ("", item["description"]),
+                "vrn_file": item["vrn_file"],
                 "dirs": copy.deepcopy(dirs), "config": config}
     else:
-        align_out = process_alignment(fastq1, fastq2, info, lane_name, lane_desc,
-                                      dirs, config)[0]
+        align_out = process_alignment(fastq1, fastq2, item, dirs, config)[0]
         data = _organize_merge_samples(align_out, dirs, config_file)
-        callable_region_bed, analysis_regions = callable.block_regions(data["work_bam"],
-                                                                       data["sam_ref"], config)
-        data["regions"] = analysis_regions
+        callable_region_bed, nblock_bed = callable.block_regions(data["work_bam"],
+                                                                 data["sam_ref"], config)
+        data["regions"] = {"nblock": nblock_bed}
         if (os.path.exists(callable_region_bed) and
                 not data["config"]["algorithm"].get("variant_regions")):
             data["config"]["algorithm"]["variant_regions"] = callable_region_bed
