@@ -4,7 +4,7 @@ Catalogs the full list of programs used in analysis, enabling reproduction of
 results and tracking of provenance in output files.
 """
 import os
-import collections
+import contextlib
 import subprocess
 
 from bcbio import broad, utils
@@ -33,7 +33,7 @@ def _broad_versioner(type):
             raise NotImplementedError(type)
     return get_version
 
-def _jar_versioner(program_name, jar_name):
+def jar_versioner(program_name, jar_name):
     """Retrieve version information based on jar file.
     """
     def get_version(config):
@@ -53,9 +53,9 @@ def _jar_versioner(program_name, jar_name):
 _alt_progs = [{"name": "gatk", "version_fn": _broad_versioner("gatk")},
               {"name": "picard", "version_fn": _broad_versioner("picard")},
               {"name": "bcbio.variation",
-               "version_fn": _jar_versioner("bcbio_variation", "bcbio.variation")},
+               "version_fn": jar_versioner("bcbio_variation", "bcbio.variation")},
               {"name": "varscan",
-               "version_fn": _jar_versioner("varscan", "VarScan")}]
+               "version_fn": jar_versioner("varscan", "VarScan")}]
 # TODO: cortex_var
 
 def _parse_from_stdoutflag(stdout, x):
@@ -73,21 +73,25 @@ def _parse_from_parenflag(stdout, x):
 def _get_cl_version(p, config):
     """Retrieve version of a single commandline program.
     """
-    prog = config_utils.get_program(p["cmd"], config)
+    try:
+        prog = config_utils.get_program(p["cmd"], config)
+    except config_utils.CmdNotFound:
+        return "NA"
     args = p.get("args", "")
 
     cmd = "{prog} {args}"
     subp = subprocess.Popen(cmd.format(**locals()), stdout=subprocess.PIPE,
                             stderr=subprocess.STDOUT,
                             shell=True)
-    if p.get("stdout_flag"):
-        version = _parse_from_stdoutflag(subp.stdout, p["stdout_flag"])
-    elif p.get("paren_flag"):
-        version = _parse_from_parenflag(subp.stdout, p["paren_flag"])
-    else:
-        print p.stdout.read()
-        raise NotImplementedError("Don't know how to extract version")
-    return version
+    with contextlib.closing(subp.stdout) as stdout:
+        if p.get("stdout_flag"):
+            v = _parse_from_stdoutflag(stdout, p["stdout_flag"])
+        elif p.get("paren_flag"):
+            v = _parse_from_parenflag(stdout, p["paren_flag"])
+        else:
+            print stdout.read()
+            raise NotImplementedError("Don't know how to extract version")
+    return v
 
 def get_versions(config):
     """Retrieve details on all programs available on the system.
